@@ -141,11 +141,15 @@ class CustomFormatter(logging.Formatter):
         if len(record.funcName) >= 30:
             record.funcName = record.funcName[:30 - 3] + '...'
 
-        return super().format(record)
+        s = super().format(record)
+        if record.exc_text:
+            s = s.replace('\n', '') + 'ERROR ->>'
+        return s
 
     def formatException(self, ei) -> str:
         output = super().formatException(ei)
-        return '--'.join(output.splitlines())
+        # return '<br>'.join(line.strip() for line in output.splitlines() if line.strip() != '')
+        repr(output)
 
 
 class ExcludeProfilingStreamHandler(logging.StreamHandler):
